@@ -3,28 +3,25 @@
 """Entry point for the CLI."""
 
 import argparse
-import functools
 import logging
 import sys
-from typing import Any, List, Optional
+from dataclasses import dataclass
+from typing import Callable, List
 
 import pkg_resources
 import pluggy
-import sqlalchemy
-from sqlalchemy.orm.session import Session
 
 import moe
-from moe.core.config import Config
-from moe.core.library.lib_item import LibItem
-from moe.core.library.session import session_scope
+from moe.config import Config, MoeSession
+from moe.library.album import Album
 
-__all__ = ["Hooks"]
+__all__ = ["PromptChoice", "query_parser"]
 
 log = logging.getLogger("moe.cli")
 
 
 class Hooks:
-    """CLI hooks specifications."""
+    """General CLI hook specifications."""
 
     @staticmethod
     @moe.hookspec
@@ -49,7 +46,6 @@ class Hooks:
 
                 func(
                     config: moe.Config,  # user config
-                    session: sqlalchemy.orm.session.Session,  # database session
                     args: argparse.Namespace,  # parsed commandline arguments
                 )
 
@@ -60,7 +56,7 @@ class Hooks:
                 edit_parser = cmd_parsers.add_parser(
                     "list",
                     description="Lists music in the library.",
-                    parents=[query.query_parser],
+                    parents=[moe.cli.query_parser],
                 )
 
         See Also:
@@ -68,37 +64,57 @@ class Hooks:
             <https://docs.python.org/3/library/argparse.html#sub-commands>`_
         """
 
-    @staticmethod
-    @moe.hookspec
-    def edit_new_items(config: Config, session: Session, items: List[LibItem]):
-        """Edit any new or changed items prior to them being added to the library.
 
-        Args:
-            config: Moe config.
-            session: Currrent db session.
-            items: Any new or changed items in the current session. The items and
-                their changes have not yet been committed to the library.
+@dataclass
+class PromptChoice:
+    """A single, user-selectable choice for a CLI prompt.
 
-        See Also:
-            The :meth:`process_new_items` hook if you wish to process any items after
-            any final edits have been made and they have been successfully added to
-            the library.
-        """
+    Attributes:
+        title: Title of the prompt choice that is displayed to the user.
+        shortcut_key: Single character the user will use to select the choice.
 
-    @staticmethod
-    @moe.hookspec
-    def process_new_items(config: Config, session: Session, items: List[LibItem]):
-        """Process any new or changed items after they have been added to the library.
+            Important:
+                Ensure the key is not currently in use by another PromptChoice.
+        func: Function to call upon this prompt choice being selected. The function
+            should return the album to be added to the library (or ``None`` if no album
+            should be added) and will be supplied the following keyword arguments:
 
-        Args:
-            config: Moe config.
-            session: Currrent db session.
-            items: Any new or changed items that have been successfully added to the
-                library during the current session.
+            * ``config``: Moe config.
+            * ``old_album``: Old album with no changes applied.
+            * ``new_album``: New album consisting of all the new changes.
+    """
 
-        See Also:
-            The :meth:`edit_new_items` hook if you wish to edit the items.
-        """
+    func_type = Callable[[Config, Album, Album], None]
+
+    title: str
+    shortcut_key: str
+    func: func_type
+
+
+# Argument parser for a query. This should be passed as a parent parser for a command.
+query_parser = argparse.ArgumentParser(
+    add_help=False, formatter_class=argparse.RawTextHelpFormatter
+)
+query_parser.add_argument("query", help="query the library for matching tracks")
+
+query_type_group = query_parser.add_mutually_exclusive_group()
+query_type_group.add_argument(
+    "-a",
+    "--album",
+    action="store_const",
+    const="album",
+    dest="query_type",
+    help="query for matching albums",
+)
+query_type_group.add_argument(
+    "-e",
+    "--extra",
+    action="store_const",
+    const="extra",
+    dest="query_type",
+    help="query for matching extras",
+)
+query_parser.set_defaults(query_type="track")
 
 
 @moe.hookimpl
@@ -143,16 +159,13 @@ def _parse_args(args: List[str], config: Config):
     _set_root_log_lvl(parsed_args)
 
     # call the sub-command's handler within a single session
-    config.init_db()
-    with session_scope() as session:
-        sqlalchemy.event.listen(
-            session, "before_flush", functools.partial(_edit_new_items, config=config)
-        )
-        sqlalchemy.event.listen(
-            session, "after_flush", functools.partial(_process_new_items, config=config)
-        )
-
-        parsed_args.func(config, session, args=parsed_args)
+    cli_session = MoeSession()
+    with cli_session.begin():
+        try:
+            parsed_args.func(config, args=parsed_args)
+        except SystemExit as err:
+            cli_session.commit()
+            raise err
 
 
 def _create_arg_parser() -> argparse.ArgumentParser:
@@ -202,49 +215,5 @@ def _set_root_log_lvl(args):
             logging.getLogger(key).setLevel(logging.WARNING)
 
 
-def _edit_new_items(
-    session: Session,
-    flush_context: sqlalchemy.orm.UOWTransaction,
-    instances: Optional[Any],
-    config: Config,
-):
-    """Runs the ``edit_new_items`` hook specification.
-
-    This uses the sqlalchemy ORM event ``before_flush`` in the background to determine
-    the time of execution and to provide any new or changed items to the hook
-    implementations.
-
-    Args:
-        session: Current db session.
-        flush_context: sqlalchemy obj which handles the details of the flush.
-        instances: List of objects passed to the ``flush()`` method.
-        config: Moe config.
-    """
-    config.plugin_manager.hook.edit_new_items(
-        config=config, session=session, items=session.new.union(session.dirty)
-    )
-
-
-def _process_new_items(
-    session: Session,
-    flush_context: sqlalchemy.orm.UOWTransaction,
-    config: Config,
-):
-    """Runs the ``process_new_items`` hook specification.
-
-    This uses the sqlalchemy ORM event ``after_flush`` in the background to determine
-    the time of execution and to provide any new or changed items to the hook
-    implementations.
-
-    Args:
-        session: Current db session.
-        flush_context: sqlalchemy obj which handles the details of the flush.
-        config: Moe config.
-    """
-    config.plugin_manager.hook.process_new_items(
-        config=config, session=session, items=session.new.union(session.dirty)
-    )
-
-
 if __name__ == "__main__":
     main()
