@@ -7,21 +7,30 @@ Note:
 """
 
 import argparse
+import logging
 from collections import OrderedDict
 from typing import Any, Dict, List
 
-import sqlalchemy
-
-import moe
-from moe.core import query
-from moe.core.config import Config
-from moe.core.library.album import Album
-from moe.core.library.extra import Extra
-from moe.core.library.lib_item import LibItem
-from moe.core.library.track import Track
+import moe.cli
+from moe import query
+from moe.config import Config
+from moe.library.album import Album
+from moe.library.extra import Extra
+from moe.library.lib_item import LibItem
+from moe.library.track import Track
 
 __all__: List[str] = []
 
+log = logging.getLogger("moe.info")
+
+
+@moe.hookimpl
+def plugin_registration(config: Config):
+    """Depend on the cli plugin."""
+    if not config.plugin_manager.has_plugin("cli"):
+        config.plugin_manager.set_blocked("info")
+        log.warning("The 'info' plugin requires the 'cli' plugin to be enabled.")
+
 
 @moe.hookimpl
 def add_command(cmd_parsers: argparse._SubParsersAction):  # noqa: WPS437
@@ -30,31 +39,22 @@ def add_command(cmd_parsers: argparse._SubParsersAction):  # noqa: WPS437
         "info",
         description="Prints information about music in the library.",
         help="print info for music in the library",
-        parents=[query.query_parser],
+        parents=[moe.cli.query_parser],
     )
     info_parser.set_defaults(func=_parse_args)
 
 
-def _parse_args(
-    config: Config, session: sqlalchemy.orm.session.Session, args: argparse.Namespace
-):
+def _parse_args(config: Config, args: argparse.Namespace):
     """Parses the given commandline arguments.
 
     Args:
         config: Configuration in use.
-        session: Current db session.
         args: Commandline arguments to parse.
 
     Raises:
         SystemExit: Query returned no tracks.
     """
-    if args.album:
-        query_type = "album"
-    elif args.extra:
-        query_type = "extra"
-    else:
-        query_type = "track"
-    items = query.query(args.query, session, query_type=query_type)
+    items = query.query(args.query, query_type=args.query_type)
 
     if not items:
         raise SystemExit(1)
