@@ -1,22 +1,14 @@
-"""Writes tags to track files.
-
-The ``move`` plugin will automatically write the tags of any altered or new items in the
-library.
-
-Note:
-    This plugin is enabled by default.
-"""
+"""Writes tags to track files."""
 
 import logging
 from typing import List
 
 import mediafile
-from sqlalchemy.orm.session import Session
 
 import moe
-from moe.core.config import Config
-from moe.core.library.lib_item import LibItem
-from moe.core.library.track import Track
+from moe.config import Config
+from moe.library.lib_item import LibItem
+from moe.library.track import Track
 
 __all__ = ["write_tags"]
 
@@ -24,12 +16,11 @@ log = logging.getLogger("moe.write")
 
 
 @moe.hookimpl
-def process_new_items(config: Config, session: Session, items: List[LibItem]):
+def process_new_items(config: Config, items: List[LibItem]):
     """Writes tags to any altered or new tracks in the library.
 
     Args:
         config: Moe config.
-        session: Currrent db session.
         items: Any new or changed items that have been committed to the database
             during the current session.
     """
